@@ -3,7 +3,7 @@ Control the simulation framework Simplace - Object oriented interface.
 
 It wraps the functions from the simplace package to a class.
 
-You need Java >= 8.0 and the Simplace simulation
+You need Java >= 11.0 and the Simplace simulation
 framework http://www.simplace.net
 
 **Example 1** - *Running a project:*
@@ -41,6 +41,10 @@ class SimplaceInstance:
                                  projectsDir, dataDir,
                                  additionalClasspathList, javaParameters)
 
+    def shutDown(self):
+        """Terminates the java virtual machine"""
+        simplace.shutDown(self._sh)
+
     def openProject(self, solution, project = None, parameters=None):
         """Create a project from the solution and optional project file."""
         simplace.openProject(self._sh, solution, project, parameters)
